#[repr(C)]pub struct DateTimePartsMetadata {
pub days_ptype: i32,
pub seconds_ptype: i32,
pub subseconds_ptype: i32,
}Fields
days_ptype: i32seconds_ptype: i32subseconds_ptype: i32Implementations
Sourceimpl DateTimePartsMetadata
impl DateTimePartsMetadata
Sourcepub fn days_ptype(&self) -> PType
pub fn days_ptype(&self) -> PType
Returns the enum value of days_ptype, or the default if the field is set to an invalid enum value.
Sourcepub fn set_days_ptype(&mut self, value: PType)
pub fn set_days_ptype(&mut self, value: PType)
Sets days_ptype to the provided enum value.
Sourcepub fn seconds_ptype(&self) -> PType
pub fn seconds_ptype(&self) -> PType
Returns the enum value of seconds_ptype, or the default if the field is set to an invalid enum value.
Sourcepub fn set_seconds_ptype(&mut self, value: PType)
pub fn set_seconds_ptype(&mut self, value: PType)
Sets seconds_ptype to the provided enum value.
Sourcepub fn subseconds_ptype(&self) -> PType
pub fn subseconds_ptype(&self) -> PType
Returns the enum value of subseconds_ptype, or the default if the field is set to an invalid enum value.
Sourcepub fn set_subseconds_ptype(&mut self, value: PType)
pub fn set_subseconds_ptype(&mut self, value: PType)
Sets subseconds_ptype to the provided enum value.
Sourceimpl DateTimePartsMetadata
impl DateTimePartsMetadata
pub fn get_days_ptype(&self) -> VortexResult<PType>
pub fn get_seconds_ptype(&self) -> VortexResult<PType>
pub fn get_subseconds_ptype(&self) -> VortexResult<PType>