pub struct DateTimePartsVTable;Trait Implementations
Sourceimpl ArrayVTable<DateTimePartsVTable> for DateTimePartsVTable
impl ArrayVTable<DateTimePartsVTable> for DateTimePartsVTable
fn len(array: &DateTimePartsArray) -> usize
fn dtype(array: &DateTimePartsArray) -> &DType
fn stats(array: &DateTimePartsArray) -> StatsSetRef<'_>
Sourceimpl CanonicalVTable<DateTimePartsVTable> for DateTimePartsVTable
impl CanonicalVTable<DateTimePartsVTable> for DateTimePartsVTable
Sourcefn canonicalize(array: &DateTimePartsArray) -> VortexResult<Canonical>
fn canonicalize(array: &DateTimePartsArray) -> VortexResult<Canonical>
Returns the canonical representation of the array. Read more
Sourcefn append_to_builder(
array: &<V as VTable>::Array,
builder: &mut dyn ArrayBuilder,
) -> Result<(), VortexError>
fn append_to_builder( array: &<V as VTable>::Array, builder: &mut dyn ArrayBuilder, ) -> Result<(), VortexError>
Writes the array into a canonical builder. Read more
Sourceimpl CastKernel for DateTimePartsVTable
impl CastKernel for DateTimePartsVTable
fn cast( &self, array: &DateTimePartsArray, dtype: &DType, ) -> VortexResult<ArrayRef>
Sourceimpl CompareKernel for DateTimePartsVTable
impl CompareKernel for DateTimePartsVTable
Sourcefn compare(
&self,
lhs: &DateTimePartsArray,
rhs: &dyn Array,
operator: Operator,
) -> VortexResult<Option<ArrayRef>>
fn compare( &self, lhs: &DateTimePartsArray, rhs: &dyn Array, operator: Operator, ) -> VortexResult<Option<ArrayRef>>
Compares two arrays and returns a new boolean array with the result of the comparison. Or, returns None if comparison is not supported.
Sourceimpl Debug for DateTimePartsVTable
impl Debug for DateTimePartsVTable
Sourceimpl EncodeVTable<DateTimePartsVTable> for DateTimePartsVTable
impl EncodeVTable<DateTimePartsVTable> for DateTimePartsVTable
Sourcefn encode(
_encoding: &DateTimePartsEncoding,
canonical: &Canonical,
_like: Option<&DateTimePartsArray>,
) -> VortexResult<Option<DateTimePartsArray>>
fn encode( _encoding: &DateTimePartsEncoding, canonical: &Canonical, _like: Option<&DateTimePartsArray>, ) -> VortexResult<Option<DateTimePartsArray>>
Try to encode a canonical array into this encoding. Read more
Sourceimpl FilterKernel for DateTimePartsVTable
impl FilterKernel for DateTimePartsVTable
Sourcefn filter(
&self,
array: &DateTimePartsArray,
mask: &Mask,
) -> VortexResult<ArrayRef>
fn filter( &self, array: &DateTimePartsArray, mask: &Mask, ) -> VortexResult<ArrayRef>
Filter an array by the provided predicate. Read more
Sourceimpl IsConstantKernel for DateTimePartsVTable
impl IsConstantKernel for DateTimePartsVTable
Sourcefn is_constant(
&self,
array: &DateTimePartsArray,
_opts: &IsConstantOpts,
) -> VortexResult<Option<bool>>
fn is_constant( &self, array: &DateTimePartsArray, _opts: &IsConstantOpts, ) -> VortexResult<Option<bool>>
Preconditions Read more
Sourceimpl OperationsVTable<DateTimePartsVTable> for DateTimePartsVTable
impl OperationsVTable<DateTimePartsVTable> for DateTimePartsVTable
Sourcefn slice(
array: &DateTimePartsArray,
start: usize,
stop: usize,
) -> VortexResult<ArrayRef>
fn slice( array: &DateTimePartsArray, start: usize, stop: usize, ) -> VortexResult<ArrayRef>
Perform a constant-time slice of the array. Read more
Sourcefn scalar_at(array: &DateTimePartsArray, index: usize) -> VortexResult<Scalar>
fn scalar_at(array: &DateTimePartsArray, index: usize) -> VortexResult<Scalar>
Fetch the scalar at the given index. Read more
Sourceimpl SerdeVTable<DateTimePartsVTable> for DateTimePartsVTable
impl SerdeVTable<DateTimePartsVTable> for DateTimePartsVTable
type Metadata = ProstMetadata<DateTimePartsMetadata>
Sourcefn metadata(array: &DateTimePartsArray) -> VortexResult<Option<Self::Metadata>>
fn metadata(array: &DateTimePartsArray) -> VortexResult<Option<Self::Metadata>>
Exports the metadata for the array. Read more
Sourcefn build(
_encoding: &DateTimePartsEncoding,
dtype: &DType,
len: usize,
metadata: &<Self::Metadata as DeserializeMetadata>::Output,
_buffers: &[ByteBuffer],
children: &dyn ArrayChildren,
) -> VortexResult<DateTimePartsArray>
fn build( _encoding: &DateTimePartsEncoding, dtype: &DType, len: usize, metadata: &<Self::Metadata as DeserializeMetadata>::Output, _buffers: &[ByteBuffer], children: &dyn ArrayChildren, ) -> VortexResult<DateTimePartsArray>
Build an array from its given parts.
Sourceimpl TakeKernel for DateTimePartsVTable
impl TakeKernel for DateTimePartsVTable
Sourcefn take(
&self,
array: &DateTimePartsArray,
indices: &dyn Array,
) -> VortexResult<ArrayRef>
fn take( &self, array: &DateTimePartsArray, indices: &dyn Array, ) -> VortexResult<ArrayRef>
Sourceimpl VTable for DateTimePartsVTable
impl VTable for DateTimePartsVTable
type Array = DateTimePartsArray
type Encoding = DateTimePartsEncoding
type ArrayVTable = DateTimePartsVTable
type CanonicalVTable = DateTimePartsVTable
type OperationsVTable = DateTimePartsVTable
type ValidityVTable = ValidityVTableFromChild
type VisitorVTable = DateTimePartsVTable
Sourcetype ComputeVTable = NotSupported
type ComputeVTable = NotSupported
Optionally enable implementing dynamic compute dispatch for this encoding.
Can be disabled by assigning to the
NotSupported type.Sourcetype EncodeVTable = DateTimePartsVTable
type EncodeVTable = DateTimePartsVTable
Optionally enable the
EncodeVTable for this encoding. This allows it to partake in
compression.
Can be disabled by assigning to the NotSupported type.Sourcetype SerdeVTable = DateTimePartsVTable
type SerdeVTable = DateTimePartsVTable
Optionally enable serde for this encoding by implementing the
SerdeVTable trait.
Can be disabled by assigning to the NotSupported type.Sourcefn id(_encoding: &Self::Encoding) -> EncodingId
fn id(_encoding: &Self::Encoding) -> EncodingId
Returns the ID of the encoding.
Sourcefn encoding(_array: &Self::Array) -> EncodingRef
fn encoding(_array: &Self::Array) -> EncodingRef
Returns the encoding for the array.
Sourceimpl ValidityChild<DateTimePartsVTable> for DateTimePartsVTable
impl ValidityChild<DateTimePartsVTable> for DateTimePartsVTable
fn validity_child(array: &DateTimePartsArray) -> &dyn Array
Sourceimpl VisitorVTable<DateTimePartsVTable> for DateTimePartsVTable
impl VisitorVTable<DateTimePartsVTable> for DateTimePartsVTable
Sourcefn visit_buffers(
_array: &DateTimePartsArray,
_visitor: &mut dyn ArrayBufferVisitor,
)
fn visit_buffers( _array: &DateTimePartsArray, _visitor: &mut dyn ArrayBufferVisitor, )
Visit the buffers of the array.
Sourcefn visit_children(
array: &DateTimePartsArray,
visitor: &mut dyn ArrayChildVisitor,
)
fn visit_children( array: &DateTimePartsArray, visitor: &mut dyn ArrayChildVisitor, )
Visit the children of the array.